#
# spec file for package ShellCheck
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name ShellCheck
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           %{pkg_name}
Version:        0.10.0
Release:        2.13
Summary:        Shell script analysis tool
License:        GPL-3.0-or-later
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{name}-%{version}/revision/1.cabal#/%{name}.cabal
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-Diff-devel
BuildRequires:  ghc-Diff-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-fgl-devel
BuildRequires:  ghc-fgl-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-regex-tdfa-devel
BuildRequires:  ghc-regex-tdfa-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  pandoc-cli
ExcludeArch:    %{ix86}

%description
The goals of ShellCheck are:

* To point out and clarify typical beginner's syntax issues, that causes a
shell to give cryptic error messages.

* To point out and clarify typical intermediate level semantic problems, that
causes a shell to behave strangely and counter-intuitively.

* To point out subtle caveats, corner cases and pitfalls, that may cause an
advanced user's otherwise working script to fail under future circumstances.

%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup
cp -p %{SOURCE1} %{name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}
pandoc -s -f markdown-smart -t man shellcheck.1.md -o shellcheck.1
install -Dpm 0644 shellcheck.1 %{buildroot}%{_mandir}/man1/shellcheck.1

%check
%cabal_test

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/shellcheck
%{_mandir}/man1/shellcheck.1%{?ext_man}

%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Dec  3 2024 Peter Simons <psimons@suse.com>
- Update ShellCheck to version 0.10.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Mar  8 2024 Peter Simons <psimons@suse.com>
- Update ShellCheck to version 0.10.0.
  [#]# v0.10.0 - 2024-03-07
  [#]## Added
  - Precompiled binaries for macOS ARM64 (darwin.aarch64)
  - Added support for busybox sh
  - Added flag --rcfile to specify an rc file by name.
  - Added `extended-analysis=true` directive to enable/disable dataflow analysis
    (with a corresponding --extended-analysis flag).
  - SC2324: Warn when x+=1 appends instead of increments
  - SC2325: Warn about multiple `!`s in dash/sh.
  - SC2326: Warn about `foo | ! bar` in bash/dash/sh.
  - SC3012: Warn about lexicographic-compare bashism in test like in [ ]
  - SC3013: Warn bashism `test _ -op/-nt/-ef _` like in [ ]
  - SC3014: Warn bashism `test _ == _` like in [ ]
  - SC3015: Warn bashism `test _ =~ _` like in [ ]
  - SC3016: Warn bashism `test -v _` like in [ ]
  - SC3017: Warn bashism `test -a _` like in [ ]
  [#]## Fixed
  - source statements with here docs now work correctly
  - "(Array.!): undefined array element" error should no longer occur
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sat Feb  4 2023 Peter Simons <psimons@suse.com>
- Update ShellCheck to version 0.9.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Dec 13 2022 Peter Simons <psimons@suse.com>
- Update ShellCheck to version 0.9.0.
  [#]# v0.9.0 - 2022-12-12
  [#]## Added
  - SC2316: Warn about 'local readonly foo' and similar (thanks, patrickxia!)
  - SC2317: Warn about unreachable commands
  - SC2318: Warn about backreferences in 'declare x=1 y=$x'
  - SC2319/SC2320: Warn when $? refers to echo/printf/[ ]/[[ ]]/test
  - SC2321: Suggest removing $((..)) in array[$((idx))]=val
  - SC2322: Suggest collapsing double parentheses in arithmetic contexts
  - SC2323: Suggest removing wrapping parentheses in a[(x+1)]=val
  [#]## Fixed
  - SC2086: Now uses DFA to make more accurate predictions about values
  - SC2086: No longer warns about values declared as integer with declare -i
  [#]## Changed
  - ShellCheck now has a Data Flow Analysis engine to make smarter decisions
    based on control flow rather than just syntax. Existing checks will
    gradually start using it, which may cause them to trigger differently
    (but more accurately).
  - Values in directives/shellcheckrc can now be quoted with '' or ""
* Thu May 19 2022 Peter Simons <psimons@suse.com>
- Update ShellCheck to version 0.8.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Nov  7 2021 psimons@suse.com
- Update ShellCheck to version 0.8.0.
- drop haddock.patch
  Upstream added a new change log file in this release. With no
  previous version to compare against, the automatic updater cannot
  reliable determine the relevante entries for this release.
* Fri Apr 23 2021 Ondřej Súkup <mimi.vx@gmail.com>
- add haddock.patch to fix build with haddock
* Thu Apr 22 2021 psimons@suse.com
- Update ShellCheck to version 0.7.2.
  Upstream does not provide a change log file.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Aug  4 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints default min disk space to 4GB and
  memory constraints that differ per architecture.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed May  6 2020 psimons@suse.com
- Update ShellCheck to version 0.7.1.
  Upstream does not provide a change log file.
* Wed Jan  1 2020 Peter Simons <psimons@suse.com>
- Drop bogus Setup.hs file to let the build succeed with ghc-8.8.x.
- Fix download URL.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Jul 30 2019 psimons@suse.com
- Update ShellCheck to version 0.7.0.
  Upstream does not provide a change log file.
* Tue Dec  4 2018 psimons@suse.com
- Update ShellCheck to version 0.6.0.
  Upstream does not provide a change log file.
* Mon Oct 15 2018 psimons@suse.com
- Update to version v0.5.0-81-ge0e46e9 from Github to fix the build
  with GHC 8.6.x.
  * Added
    Command line option --severity/-S for filtering by minimum severity
    SC2236/SC2237: Suggest -n/-z instead of ! -z/-n
    SC2238: Warn when redirecting to a known command name, e.g. ls > rm
  * Changed
    Most warnings now have useful end positions
    SC1117 about unknown double-quoted escape sequences has been retired
  * Fixed
    SC2021 no longer triggers for equivalence classes like '[=e=]'
    SC2221/SC2222 no longer mistriggers on fall-through case branches
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update ShellCheck to version 0.5.0.
  * Added SC2233/SC2234/SC2235: Suggest removing or replacing (..) around tests
* Wed May 16 2018 psimons@suse.com
- Update to version v0.4.7-106-g235bf66 from Github to fix the
  build with GHC 8.4.x.
  * Added:
    SC2232: Warn about invalid arguments to sudo
    SC2231: Suggest quoting expansions in for loop globs
    SC2229: Warn about 'read $var'
    SC2227: Warn about redirections in the middle of 'find' commands
    SC2224,SC2225,SC2226: Warn when using mv/cp/ln without a destination
    SC2223: Quote warning specific to : ${var=value}
    SC1131: Warn when using elseif or elsif
    SC1128: Warn about blanks/comments before shebang
    SC1127: Warn about C-style comments
  * Fixed:
    Annotations intended for a command's here documents now work
    Escaped characters inside groups in =~ regexes now parse
    Associative arrays are now respected in arithmetic contexts
    SC1087 about $var[@] now correctly triggers on any index
    Bad expansions in here documents are no longer ignored
    FD move operations like {fd}>1- now parse correctly
  * Changed:
    SC1073: 'else if' is now parsed correctly and not like 'elif'
    SC2163: 'export $name' can now be silenced with 'export ${name?}'
    SC2183: Now warns when printf arg count is not a multiple of format count
* Thu Apr 12 2018 guillaume@opensuse.org
- Add _constraints to avoid OOM error with a special case for
  aarch64 which needs lots of RAM.
* Thu Apr 12 2018 psimons@suse.com
- Update ShellCheck to version 0.4.7 revision 1.
  A more detailed change log is not available.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 0.4.6 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.4.5 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.4.4 revision 0 with cabal2obs.
* Sat May 21 2016 mimi.vx@gmail.com
- update to 0.4.4
* Sun Jan 24 2016 mimi.vx@gmail.com
- update to 0.4.3
* Tue Jan 12 2016 mimi.vx@gmail.com
- update to 0.4.2
* Sun Sep  6 2015 mimi.vx@gmail.com
- initial commit
